==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/GetDisasterRecoveryConfigPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property alias The Disaster Recovery configuration name
 * @property namespaceName The Namespace name
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class GetDisasterRecoveryConfigPlainArgs(
    public val alias: String,
    public val namespaceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs =
        com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs.builder()
            .alias(alias.let({ args0 -> args0 }))
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDisasterRecoveryConfigPlainArgs].
 */
@PulumiTagMarker
public class GetDisasterRecoveryConfigPlainArgsBuilder internal constructor() {
    private var alias: String? = null

    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("puggkiiudcactodc")
    public suspend fun alias(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.alias = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("kvnmurauxfdujgvf")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("jmjetxgiqpqdashl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDisasterRecoveryConfigPlainArgs = GetDisasterRecoveryConfigPlainArgs(
        alias = alias ?: throw PulumiNullFieldException("alias"),
        namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/GetDisasterRecoveryConfigPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property alias The Disaster Recovery configuration name
 * @property namespaceName The Namespace name
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class GetDisasterRecoveryConfigPlainArgs(
    public val alias: String,
    public val namespaceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs =
        com.pulumi.azurenative.eventhub.inputs.GetDisasterRecoveryConfigPlainArgs.builder()
            .alias(alias.let({ args0 -> args0 }))
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDisasterRecoveryConfigPlainArgs].
 */
@PulumiTagMarker
public class GetDisasterRecoveryConfigPlainArgsBuilder internal constructor() {
    private var alias: String? = null

    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("enqvgwmaxoeexjib")
    public suspend fun alias(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.alias = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("yjbmjvdmdpoparmq")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("vjlwgqrpfuqbwyti")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDisasterRecoveryConfigPlainArgs = GetDisasterRecoveryConfigPlainArgs(
        alias = alias ?: throw PulumiNullFieldException("alias"),
        namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
